# Changelog

## [0.5.0a3](https://github.com/JarbasHiveMind/hivemind-websocket-client/tree/0.5.0a3) (2026-03-23)

[Full Changelog](https://github.com/JarbasHiveMind/hivemind-websocket-client/compare/0.5.0a2...0.5.0a3)

## [0.5.0a2](https://github.com/JarbasHiveMind/hivemind-websocket-client/tree/0.5.0a2) (2026-03-23)

[Full Changelog](https://github.com/JarbasHiveMind/hivemind-websocket-client/compare/0.5.0a1...0.5.0a2)

## [0.5.0a1](https://github.com/JarbasHiveMind/hivemind-websocket-client/tree/0.5.0a1) (2026-03-23)

[Full Changelog](https://github.com/JarbasHiveMind/hivemind-websocket-client/compare/0.4.6a3...0.5.0a1)

**Merged pull requests:**

- feat: add flood-based PING network discovery and hive topology mapping [\#90](https://github.com/JarbasHiveMind/hivemind-websocket-client/pull/90) ([JarbasAl](https://github.com/JarbasAl))

## [0.4.6a3](https://github.com/JarbasHiveMind/hivemind-websocket-client/tree/0.4.6a3) (2026-03-23)

[Full Changelog](https://github.com/JarbasHiveMind/hivemind-websocket-client/compare/0.4.6a2...0.4.6a3)

**Merged pull requests:**

- chore: typing, Docs, tests [\#91](https://github.com/JarbasHiveMind/hivemind-websocket-client/pull/91) ([JarbasAl](https://github.com/JarbasAl))

## [0.4.6a2](https://github.com/JarbasHiveMind/hivemind-websocket-client/tree/0.4.6a2) (2026-03-21)

[Full Changelog](https://github.com/JarbasHiveMind/hivemind-websocket-client/compare/0.4.6a1...0.4.6a2)

**Merged pull requests:**

- Fix: z85 [\#87](https://github.com/JarbasHiveMind/hivemind-websocket-client/pull/87) ([JarbasAl](https://github.com/JarbasAl))

## [0.4.6a1](https://github.com/JarbasHiveMind/hivemind-websocket-client/tree/0.4.6a1) (2026-01-23)

[Full Changelog](https://github.com/JarbasHiveMind/hivemind-websocket-client/compare/0.4.5a3...0.4.6a1)

**Merged pull requests:**

- fix: add warning if websocket connection isnt open [\#83](https://github.com/JarbasHiveMind/hivemind-websocket-client/pull/83) ([JarbasAl](https://github.com/JarbasAl))

## [0.4.5a3](https://github.com/JarbasHiveMind/hivemind-websocket-client/tree/0.4.5a3) (2026-01-23)

[Full Changelog](https://github.com/JarbasHiveMind/hivemind-websocket-client/compare/0.4.5a2...0.4.5a3)

**Merged pull requests:**

- chore\(deps\): update actions/checkout action to v6 [\#79](https://github.com/JarbasHiveMind/hivemind-websocket-client/pull/79) ([renovate[bot]](https://github.com/apps/renovate))

## [0.4.5a2](https://github.com/JarbasHiveMind/hivemind-websocket-client/tree/0.4.5a2) (2025-12-19)

[Full Changelog](https://github.com/JarbasHiveMind/hivemind-websocket-client/compare/0.4.5a1...0.4.5a2)

**Merged pull requests:**

- chore\(deps\): update actions/setup-python action to v6 [\#81](https://github.com/JarbasHiveMind/hivemind-websocket-client/pull/81) ([renovate[bot]](https://github.com/apps/renovate))

## [0.4.5a1](https://github.com/JarbasHiveMind/hivemind-websocket-client/tree/0.4.5a1) (2025-12-18)

[Full Changelog](https://github.com/JarbasHiveMind/hivemind-websocket-client/compare/0.4.4...0.4.5a1)

**Merged pull requests:**

- chore: Configure Renovate [\#76](https://github.com/JarbasHiveMind/hivemind-websocket-client/pull/76) ([renovate[bot]](https://github.com/apps/renovate))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
